@@ -171,9 +171,6 @@ type upstreamWrapper struct {
 }
 
 func (u *upstreamWrapper) Exchange(qCtx *handler.Context) (*dns.Msg, error) {
-	if qCtx.IsTCPClient() {
-		return u.u.ExchangeNoTruncated(qCtx.Q())
-	}
 	return u.u.Exchange(qCtx.Q())
 }
 
